The document module
===================

.. automodule:: parce.document
    :members:
    :special-members: __delitem__, __format__, __getitem__, __str__, __setitem__,
    :undoc-members:
    :show-inheritance:

